@@ -1,7 +1,5 @@
 <?php
-/*
- *  $Id: aa9e601342201eab334a91cdf4e3b20c15913ca8 $
- *
+/**
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
@@ -25,17 +23,16 @@ include_once 'phing/system/lang/NullPointerException.php';
 /**
  * An abstract representation of file and directory pathnames.
  *
- * @version   $Id: aa9e601342201eab334a91cdf4e3b20c15913ca8 $
  * @package   phing.system.io
  */
-class PhingFile {
-
+class PhingFile
+{
     /** separator string, static, obtained from FileSystem */
     public static $separator;
 
     /** path separator string, static, obtained from FileSystem (; or :)*/
     public static $pathSeparator;
-    
+
     /**
      * This abstract pathname's normalized pathname string.  A normalized
      * pathname string uses the default name-separator character and does not
@@ -49,9 +46,18 @@ class PhingFile {
      */
     private $prefixLength = 0;
 
-    /** constructor */
-    function __construct($arg1 = null, $arg2 = null) {
-        
+    /**
+     * constructor
+     *
+     * @param mixed $arg1
+     * @param mixed $arg2
+     *
+     * @throws IOException
+     * @throws NullPointerException
+     */
+    public function __construct($arg1 = null, $arg2 = null)
+    {
+
         if (self::$separator === null || self::$pathSeparator === null) {
             $fs = FileSystem::getFileSystem();
             self::$separator = $fs->getSeparator();
@@ -63,7 +69,7 @@ class PhingFile {
             $this->_constructFileParentStringChild($arg1, $arg2);
         } elseif (is_string($arg1) && ($arg2 === null)) {
             $this->_constructPathname($arg1);
-        } elseif(is_string($arg1) && is_string($arg2)) {
+        } elseif (is_string($arg1) && is_string($arg2)) {
             $this->_constructStringParentStringChild($arg1, $arg2);
         } else {
             if ($arg1 === null) {
@@ -76,21 +82,23 @@ class PhingFile {
 
     /**
      * Returns the length of this abstract pathname's prefix.
-     * 
+     *
      * @return int
      */
-    function getPrefixLength() {
+    public function getPrefixLength()
+    {
         return (int) $this->prefixLength;
     }
-    
+
     /* -- constructors not called by signature match, so we need some helpers --*/
 
     /**
-     * 
-     * Enter description here ...
-     * @param unknown_type $pathname
+     * @param string $pathname
+     *
+     * @throws NullPointerException
      */
-    protected function _constructPathname($pathname) {
+    protected function _constructPathname($pathname)
+    {
         // obtain ref to the filesystem layer
         $fs = FileSystem::getFileSystem();
 
@@ -103,12 +111,14 @@ class PhingFile {
     }
 
     /**
-     * 
+     *
      * Enter description here ...
      * @param unknown_type $parent
      * @param unknown_type $child
+     * @throws NullPointerException
      */
-    protected function _constructStringParentStringChild($parent, $child = null) {
+    protected function _constructStringParentStringChild($parent, $child = null)
+    {
         // obtain ref to the filesystem layer
         $fs = FileSystem::getFileSystem();
 
@@ -128,12 +138,14 @@ class PhingFile {
     }
 
     /**
-     * 
+     *
      * Enter description here ...
      * @param unknown_type $parent
      * @param unknown_type $child
+     * @throws NullPointerException
      */
-    protected function _constructFileParentStringChild($parent, $child = null) {
+    protected function _constructFileParentStringChild($parent, $child = null)
+    {
         // obtain ref to the filesystem layer
         $fs = FileSystem::getFileSystem();
 
@@ -161,16 +173,18 @@ class PhingFile {
      * sequence.  If the pathname's name sequence is empty, then the empty
      * string is returned.
      *
-     * @return  The name of the file or directory denoted by this abstract
-     *          pathname, or the empty string if this pathname's name sequence
-     *          is empty
+     * @return string The name of the file or directory denoted by this abstract
+     *                pathname, or the empty string if this pathname's name sequence
+     *                is empty
      */
-    function getName() {
+    public function getName()
+    {
         // that's a lastIndexOf
         $index = ((($res = strrpos($this->path, self::$separator)) === false) ? -1 : $res);
         if ($index < $this->prefixLength) {
             return substr($this->path, $this->prefixLength);
         }
+
         return substr($this->path, $index + 1);
     }
 
@@ -183,18 +197,21 @@ class PhingFile {
      * If the name sequence is empty then the pathname does not name a parent
      * directory.
      *
-     * @return  The pathname string of the parent directory named by this
-     *          abstract pathname, or null if this pathname does not name a parent
+     * @return string $pathname string of the parent directory named by this
+     *                          abstract pathname, or null if this pathname does not name a parent
      */
-    function getParent() {
+    public function getParent()
+    {
         // that's a lastIndexOf
         $index = ((($res = strrpos($this->path, self::$separator)) === false) ? -1 : $res);
         if ($index < $this->prefixLength) {
             if (($this->prefixLength > 0) && (strlen($this->path) > $this->prefixLength)) {
                 return substr($this->path, 0, $this->prefixLength);
             }
+
             return null;
         }
+
         return substr($this->path, 0, $index);
     }
 
@@ -207,15 +224,17 @@ class PhingFile {
      * last.  If the name sequence is empty then the pathname does not name
      * a parent directory.
      *
-     * @return  The abstract pathname of the parent directory named by this
-     *          abstract pathname, or null if this pathname
-     *          does not name a parent
+     * @return The abstract pathname of the parent directory named by this
+     *             abstract pathname, or null if this pathname
+     *             does not name a parent
      */
-    function getParentFile() {
+    public function getParentFile()
+    {
         $p = $this->getParent();
         if ($p === null) {
             return null;
         }
+
         return new PhingFile((string) $p, (int) $this->prefixLength);
     }
 
@@ -226,7 +245,8 @@ class PhingFile {
      *
      * @return string The string form of this abstract pathname
      */
-    function getPath() {
+    public function getPath()
+    {
         return (string) $this->path;
     }
 
@@ -239,7 +259,7 @@ class PhingFile {
      *
      * @uses getPath()
      */
-    function getPathWithoutBase($basedir)
+    public function getPathWithoutBase($basedir)
     {
         if (!StringHelper::endsWith(self::$separator, $basedir)) {
             $basedir .= self::$separator;
@@ -249,6 +269,7 @@ class PhingFile {
             //path does not begin with basedir, we don't modify it
             return $path;
         }
+
         return substr($path, strlen($basedir));
     }
 
@@ -261,7 +282,8 @@ class PhingFile {
      *
      * @return boolean true if this abstract pathname is absolute, false otherwise
      */
-    function isAbsolute() {
+    public function isAbsolute()
+    {
         return ($this->prefixLength !== 0);
     }
 
@@ -285,8 +307,10 @@ class PhingFile {
      *                directory as this abstract pathname
      * @see    #isAbsolute()
      */
-    function getAbsolutePath() {
-        $fs = FileSystem::getFileSystem();        
+    public function getAbsolutePath()
+    {
+        $fs = FileSystem::getFileSystem();
+
         return $fs->resolveFile($this);
     }
 
@@ -294,10 +318,11 @@ class PhingFile {
      * Returns the absolute form of this abstract pathname.  Equivalent to
      * getAbsolutePath.
      *
-     * @return string The absolute abstract pathname denoting the same file or
+     * @return PhingFile The absolute abstract pathname denoting the same file or
      *                directory as this abstract pathname
      */
-    function getAbsoluteFile() {
+    public function getAbsoluteFile()
+    {
         return new PhingFile((string) $this->getAbsolutePath());
     }
 
@@ -326,8 +351,10 @@ class PhingFile {
      * @return string The canonical pathname string denoting the same file or
      *                directory as this abstract pathname
      */
-    function getCanonicalPath() {
+    public function getCanonicalPath()
+    {
         $fs = FileSystem::getFileSystem();
+
         return $fs->canonicalize($this->path);
     }
 
@@ -336,10 +363,11 @@ class PhingFile {
      * Returns the canonical form of this abstract pathname.  Equivalent to
      * getCanonicalPath(.
      *
-     * @return  PhingFile The canonical pathname string denoting the same file or
-     *          directory as this abstract pathname
+     * @return PhingFile The canonical pathname string denoting the same file or
+     *                   directory as this abstract pathname
      */
-    function getCanonicalFile() {
+    public function getCanonicalFile()
+    {
         return new PhingFile($this->getCanonicalPath());
     }
 
@@ -359,7 +387,8 @@ class PhingFile {
      * @todo   Not implemented yet
      *
      */
-    function toURL() {
+    public function toURL()
+    {
         /*
         // URL class not implemented yet
         return new URL("file", "", $this->_slashify($this->getAbsolutePath(), $this->isDirectory()));
@@ -371,24 +400,27 @@ class PhingFile {
      * @todo   Not implemented yet
      * @return void
      */
-    function toURI() {
+    public function toURI()
+    {
         /*
         $f = $this->getAbsoluteFile();
            $sp = (string) $this->slashify($f->getPath(), $f->isDirectory());
            if (StringHelper::startsWith('//', $sp))
         $sp = '//' + sp;
+
            return new URI('file', null, $sp, null);
         */
     }
 
     /**
-     * 
+     *
      * Enter description here ...
      * @param  PhingFile|string $path
-     * @param  boolean $isDirectory
+     * @param  boolean          $isDirectory
      * @return string
      */
-    function _slashify($path, $isDirectory) {
+    public function _slashify($path, $isDirectory)
+    {
         $p = (string) $path;
 
         if (self::$separator !== '/') {
@@ -396,11 +428,11 @@ class PhingFile {
         }
 
         if (!StringHelper::startsWith('/', $p)) {
-            $p = '/'.$p;
+            $p = '/' . $p;
         }
 
         if (!StringHelper::endsWith('/', $p) && $isDirectory) {
-            $p = $p.'/';
+            $p = $p . '/';
         }
 
         return $p;
@@ -416,12 +448,14 @@ class PhingFile {
      *                 abstract pathname exists and can be read by the
      *                 application; false otherwise
      */
-    function canRead() {
+    public function canRead()
+    {
         $fs = FileSystem::getFileSystem();
 
         if ($fs->checkAccess($this)) {
             return (boolean) @is_link($this->getAbsolutePath()) || @is_readable($this->getAbsolutePath());
         }
+
         return false;
     }
 
@@ -434,8 +468,10 @@ class PhingFile {
      *                 the application is allowed to write to the file;
      *                 false otherwise.
      */
-    function canWrite() {
+    public function canWrite()
+    {
         $fs = FileSystem::getFileSystem();
+
         return $fs->checkAccess($this, true);
     }
 
@@ -445,15 +481,18 @@ class PhingFile {
      * @return boolean true if and only if the file denoted by this
      *                 abstract pathname exists; false otherwise
      */
-    function exists() {
+    public function exists()
+    {
         clearstatcache();
 
         if (is_link($this->path)) {
             return true;
-        } else if ($this->isDirectory()) {
-            return true;
         } else {
-            return @file_exists($this->path) || is_link($this->path);
+            if ($this->isDirectory()) {
+                return true;
+            } else {
+                return @file_exists($this->path) || is_link($this->path);
+            }
         }
     }
 
@@ -461,16 +500,19 @@ class PhingFile {
      * Tests whether the file denoted by this abstract pathname is a
      * directory.
      *
+     * @throws IOException
      * @return boolean true if and only if the file denoted by this
      *                 abstract pathname exists and is a directory;
      *                 false otherwise
      */
-    function isDirectory() {
+    public function isDirectory()
+    {
         clearstatcache();
         $fs = FileSystem::getFileSystem();
         if ($fs->checkAccess($this) !== true) {
-            throw new IOException("No read access to ".$this->path);
+            throw new IOException("No read access to " . $this->path);
         }
+
         return @is_dir($this->path) && !@is_link($this->path);
     }
 
@@ -484,7 +526,8 @@ class PhingFile {
      *                 abstract pathname exists and is a normal file;
      *                 false otherwise
      */
-    function isFile() {
+    public function isFile()
+    {
         clearstatcache();
         //$fs = FileSystem::getFileSystem();
         return @is_file($this->path);
@@ -498,21 +541,25 @@ class PhingFile {
      * hidden if it has been marked as such in the filesystem. Currently there
      * seems to be no way to dermine isHidden on Win file systems via PHP
      *
+     * @throws IOException
      * @return boolean true if and only if the file denoted by this
      *                 abstract pathname is hidden according to the conventions of the
      *                 underlying platform
      */
-    function isHidden() {
+    public function isHidden()
+    {
         $fs = FileSystem::getFileSystem();
         if ($fs->checkAccess($this) !== true) {
-            throw new IOException("No read access to ".$this->path);
+            throw new IOException("No read access to " . $this->path);
         }
-        return (($fs->getBooleanAttributes($this) & $fs->BA_HIDDEN) !== 0);
+
+        return (($fs->getBooleanAttributes($this) & FileSystem::BA_HIDDEN) !== 0);
     }
-    
+
     /**
      * Tests whether the file denoted by this abstract pathname is a symbolic link.
      *
+     * @throws IOException
      * @return boolean true if and only if the file denoted by this
      *                 abstract pathname exists and is a symbolic link;
      *                 false otherwise
@@ -522,8 +569,9 @@ class PhingFile {
         clearstatcache();
         $fs = FileSystem::getFileSystem();
         if ($fs->checkAccess($this) !== true) {
-            throw new IOException("No read access to ".$this->path);
+            throw new IOException("No read access to " . $this->path);
         }
+
         return @is_link($this->path);
     }
 
@@ -541,16 +589,19 @@ class PhingFile {
      * Returns the time that the file denoted by this abstract pathname was
      * last modified.
      *
+     * @throws IOException
      * @return int An integer value representing the time the file was
-     *             last modified, measured in milliseconds since the epoch
+     *             last modified, measured in seconds since the epoch
      *             (00:00:00 GMT, January 1, 1970), or 0 if the
      *             file does not exist or if an I/O error occurs
      */
-    function lastModified() {
+    public function lastModified()
+    {
         $fs = FileSystem::getFileSystem();
         if ($fs->checkAccess($this) !== true) {
             throw new IOException("No read access to " . $this->path);
         }
+
         return $fs->getLastModifiedTime($this);
     }
 
@@ -558,14 +609,17 @@ class PhingFile {
      * Returns the length of the file denoted by this abstract pathname.
      * The return value is unspecified if this pathname denotes a directory.
      *
+     * @throws IOException
      * @return int The length, in bytes, of the file denoted by this abstract
      *             pathname, or 0 if the file does not exist
      */
-    function length() {
+    public function length()
+    {
         $fs = FileSystem::getFileSystem();
         if ($fs->checkAccess($this) !== true) {
-            throw new IOException("No read access to ".$this->path."\n");
+            throw new IOException("No read access to " . $this->path . "\n");
         }
+
         return $fs->getLength($this);
     }
 
@@ -575,13 +629,15 @@ class PhingFile {
      * @return string
      * @throws Exception - if file cannot be read
      */
-    function contents() {
+    public function contents()
+    {
         if (!$this->canRead() || !$this->isFile()) {
             throw new IOException("Cannot read file contents!");
         }
+
         return file_get_contents($this->getAbsolutePath());
     }
-    
+
     /* -- File operations -- */
 
     /**
@@ -591,13 +647,17 @@ class PhingFile {
      * are a single operation that is atomic with respect to all other
      * filesystem activities that might affect the file.
      *
-     * @return boolean true if the named file does not exist and was
-     *                 successfully created; <code>false</code> if the named file
-     *                 already exists
-     * @throws IOException if file can't be created
+     * @param bool $parents
+     * @param int $mode
+     * @throws IOException
+     * @return boolean     true if the named file does not exist and was
+     *                     successfully created; <code>false</code> if the named file
+     *                     already exists
      */
-    function createNewFile($parents=true, $mode=0777) {
+    public function createNewFile($parents = true, $mode = 0777)
+    {
         $file = FileSystem::getFileSystem()->createNewFile($this->path);
+
         return $file;
     }
 
@@ -606,14 +666,18 @@ class PhingFile {
      * this pathname denotes a directory, then the directory must be empty in
      * order to be deleted.
      *
+     * @param bool $recursive
+     * @throws IOException
      * @return boolean true if and only if the file or directory is
      *                 successfully deleted; false otherwise
      */
-    function delete($recursive = false) {
+    public function delete($recursive = false)
+    {
         $fs = FileSystem::getFileSystem();
         if ($fs->canDelete($this) !== true) {
-            throw new IOException("Cannot delete " . $this->path . "\n"); 
+            throw new IOException("Cannot delete " . $this->path . "\n");
         }
+
         return $fs->delete($this, $recursive);
     }
 
@@ -627,7 +691,8 @@ class PhingFile {
      * request.  This method should therefore be used with care.
      *
      */
-    function deleteOnExit() {
+    public function deleteOnExit()
+    {
         $fs = FileSystem::getFileSystem();
         $fs->deleteOnExit($this);
     }
@@ -647,24 +712,27 @@ class PhingFile {
      * will appear in any specific order; they are not, in particular,
      * guaranteed to appear in alphabetical order.
      *
-     * @param $filter string
+     * @param string $filter
      * @return array An array of strings naming the files and directories in the
      *               directory denoted by this abstract pathname.  The array will be
      *               empty if the directory is empty.  Returns null if
      *               this abstract pathname does not denote a directory, or if an
      *               I/O error occurs.
      */
-    function listDir($filter = null) {
+    public function listDir($filter = null)
+    {
         $fs = FileSystem::getFileSystem();
+
         return $fs->lister($this, $filter);
     }
 
     /**
-     * 
-     * Enter description here ...
-     * @param PhingFile[] $filter
+     * @param string $filter
+     *
+     * @return array
      */
-    function listFiles($filter = null) {
+    public function listFiles($filter = null)
+    {
         $ss = $this->listDir($filter);
         if ($ss === null) {
             return null;
@@ -672,8 +740,9 @@ class PhingFile {
         $n = count($ss);
         $fs = array();
         for ($i = 0; $i < $n; $i++) {
-            $fs[$i] = new PhingFile((string)$this->path, (string)$ss[$i]);
+            $fs[$i] = new PhingFile((string) $this->path, (string) $ss[$i]);
         }
+
         return $fs;
     }
 
@@ -683,12 +752,14 @@ class PhingFile {
      * operation fails it may have succeeded in creating some of the necessary
      * parent directories.
      *
-     * @return boolean true if and only if the directory was created,
-     *                 along with all necessary parent directories; false
-     *                 otherwise
+     * @param int $mode
      * @throws IOException
+     * @return boolean     true if and only if the directory was created,
+     *                     along with all necessary parent directories; false
+     *                     otherwise
      */
-    function mkdirs($mode = 0755) {
+    public function mkdirs($mode = 0755)
+    {
         if ($this->exists()) {
             return false;
         }
@@ -698,23 +769,27 @@ class PhingFile {
             }
         } catch (IOException $ioe) {
             // IOException from mkdir() means that directory propbably didn't exist.
-        }        
+        }
         $parentFile = $this->getParentFile();
+
         return (($parentFile !== null) && ($parentFile->mkdirs($mode) && $this->mkdir($mode)));
     }
 
     /**
      * Creates the directory named by this abstract pathname.
      *
-     * @return boolean true if and only if the directory was created; false otherwise
+     * @param int $mode
      * @throws IOException
+     * @return boolean     true if and only if the directory was created; false otherwise
      */
-    function mkdir($mode = 0755) {
+    public function mkdir($mode = 0755)
+    {
         $fs = FileSystem::getFileSystem();
 
         if ($fs->checkAccess(new PhingFile($this->path), true) !== true) {
             throw new IOException("No write access to " . $this->getPath());
         }
+
         return $fs->createDirectory($this, $mode);
     }
 
@@ -722,13 +797,16 @@ class PhingFile {
      * Renames the file denoted by this abstract pathname.
      *
      * @param  PhingFile $destFile The new abstract pathname for the named file
-     * @return boolean true if and only if the renaming succeeded; false otherwise
+     * @throws IOException
+     * @return boolean   true if and only if the renaming succeeded; false otherwise
      */
-    function renameTo(PhingFile $destFile) {
+    public function renameTo(PhingFile $destFile)
+    {
         $fs = FileSystem::getFileSystem();
         if ($fs->checkAccess($this) !== true) {
-            throw new IOException("No write access to ".$this->getPath());
+            throw new IOException("No write access to " . $this->getPath());
         }
+
         return $fs->rename($this, $destFile);
     }
 
@@ -736,19 +814,22 @@ class PhingFile {
      * Simple-copies file denoted by this abstract pathname into another
      * PhingFile
      *
-     * @param  PhingFile $destFile  The new abstract pathname for the named file
-     * @return boolean true if and only if the renaming succeeded; false otherwise
+     * @param  PhingFile $destFile The new abstract pathname for the named file
+     * @throws IOException
+     * @return boolean   true if and only if the renaming succeeded; false otherwise
      */
-    function copyTo(PhingFile $destFile) {
+    public function copyTo(PhingFile $destFile)
+    {
         $fs = FileSystem::getFileSystem();
 
         if ($fs->checkAccess($this) !== true) {
-            throw new IOException("No read access to ".$this->getPath()."\n");
+            throw new IOException("No read access to " . $this->getPath() . "\n");
         }
 
         if ($fs->checkAccess($destFile, true) !== true) {
-            throw new IOException("File::copyTo() No write access to ".$destFile->getPath());
+            throw new IOException("File::copyTo() No write access to " . $destFile->getPath());
         }
+
         return $fs->copy($this, $destFile);
     }
 
@@ -764,16 +845,19 @@ class PhingFile {
      * that was passed to this method.
      *
      * @param  int $time The new last-modified time, measured in milliseconds since
-     *                   the epoch (00:00:00 GMT, January 1, 1970)
+     *                       the epoch (00:00:00 GMT, January 1, 1970)
+     * @throws Exception
      * @return boolean true if and only if the operation succeeded; false otherwise
      */
-    function setLastModified($time) {
+    public function setLastModified($time)
+    {
         $time = (int) $time;
         if ($time < 0) {
             throw new Exception("IllegalArgumentException, Negative $time\n");
         }
 
         $fs = FileSystem::getFileSystem();
+
         return $fs->setLastModifiedTime($this, $time);
     }
 
@@ -784,65 +868,87 @@ class PhingFile {
      * marked to allow write access.  Whether or not a read-only file or
      * directory may be deleted depends upon the underlying system.
      *
+     * @throws IOException
      * @return boolean true if and only if the operation succeeded; false otherwise
      */
-    function setReadOnly() {
+    public function setReadOnly()
+    {
         $fs = FileSystem::getFileSystem();
         if ($fs->checkAccess($this, true) !== true) {
             // Error, no write access
             throw new IOException("No write access to " . $this->getPath());
         }
+
         return $fs->setReadOnly($this);
     }
 
     /**
      * Sets the owner of the file.
+     *
      * @param mixed $user User name or number.
+     *
+     * @throws IOException
      */
-    public function setUser($user) {
+    public function setUser($user)
+    {
         $fs = FileSystem::getFileSystem();
+
         return $fs->chown($this->getPath(), $user);
     }
-    
+
     /**
      * Retrieve the owner of this file.
-     * @return int User ID of the owner of this file. 
+     *
+     * @return int User ID of the owner of this file.
      */
-    function getUser() {
+    public function getUser()
+    {
         return @fileowner($this->getPath());
     }
-    
+
     /**
      * Sets the group of the file.
-     * @param mixed $user User name or number.
+     *
+     * @param string $group
+     *
+     * @throws IOException
      */
-    public function setGroup($group) {
+    public function setGroup($group)
+    {
         $fs = FileSystem::getFileSystem();
+
         return $fs->chgrp($this->getPath(), $group);
     }
-    
+
     /**
      * Retrieve the group of this file.
-     * @return int User ID of the owner of this file. 
+     *
+     * @return int User ID of the owner of this file.
      */
-    function getGroup() {
+    public function getGroup()
+    {
         return @filegroup($this->getPath());
     }
 
     /**
      * Sets the mode of the file
+     *
      * @param int $mode Ocatal mode.
      */
-    function setMode($mode) {
+    public function setMode($mode)
+    {
         $fs = FileSystem::getFileSystem();
+
         return $fs->chmod($this->getPath(), $mode);
     }
 
     /**
      * Retrieve the mode of this file.
+     *
      * @return int
      */
-    function getMode() {
+    public function getMode()
+    {
         return @fileperms($this->getPath());
     }
 
@@ -881,8 +987,10 @@ class PhingFile {
      *               could not be determined.  The array will be empty if there are
      *               no filesystem roots.
      */
-    function listRoots() {
+    public function listRoots()
+    {
         $fs = FileSystem::getFileSystem();
+
         return (array) $fs->listRoots();
     }
 
@@ -892,7 +1000,8 @@ class PhingFile {
      * Returns the path to the temp directory.
      * @return string
      */
-    public static function getTempDir() {
+    public static function getTempDir()
+    {
         return Phing::getProperty('php.tmpdir');
     }
 
@@ -903,11 +1012,17 @@ class PhingFile {
      * Then, the file is locked for exclusive reading/writing.
      *
      * @author manuel holtgrewe, grin@gmx.net
+     *
+     * @param $prefix
+     * @param $suffix
+     * @param PhingFile $directory
+     *
      * @throws IOException
      * @return PhingFile
      */
-    public static function createTempFile($prefix, $suffix, PhingFile $directory) {
-        
+    public static function createTempFile($prefix, $suffix, PhingFile $directory)
+    {
+
         // quick but efficient hack to create a unique filename ;-)
         $result = null;
         do {
@@ -923,18 +1038,16 @@ class PhingFile {
 
     /**
      * If necessary, $File the lock on $File is removed and then the file is
-     * deleted
-     *
-     * @access      public
+     * deleted.
      */
-    function removeTempFile() {
+    public function removeTempFile()
+    {
         $fs = FileSystem::getFileSystem();
         // catch IO Exception
         $fs->unlock($this);
         $this->delete();
     }
 
-
     /* -- Basic infrastructure -- */
 
     /**
@@ -946,13 +1059,15 @@ class PhingFile {
      * @param PhingFile $file Th file whose pathname sould be compared to the pathname of this file.
      *
      * @return int Zero if the argument is equal to this abstract pathname, a
-     *        value less than zero if this abstract pathname is
-     *        lexicographically less than the argument, or a value greater
-     *        than zero if this abstract pathname is lexicographically
-     *        greater than the argument
+     *             value less than zero if this abstract pathname is
+     *             lexicographically less than the argument, or a value greater
+     *             than zero if this abstract pathname is lexicographically
+     *             greater than the argument
      */
-    function compareTo(PhingFile $file) {
+    public function compareTo(PhingFile $file)
+    {
         $fs = FileSystem::getFileSystem();
+
         return $fs->compare($this, $file);
     }
 
@@ -964,28 +1079,33 @@ class PhingFile {
      * pathnames are equal depends upon the underlying system.  On UNIX
      * systems, alphabetic case is significant in comparing pathnames; on Win32
      * systems it is not.
+     *
+     * @param PhingFile $obj
+     *
      * @return boolean
      */
-    function equals($obj) {
+    public function equals($obj)
+    {
         if (($obj !== null) && ($obj instanceof PhingFile)) {
             return ($this->compareTo($obj) === 0);
         }
+
         return false;
     }
 
     /**
      * Backwards compatibility - @see __toString()
-     * 
+     *
      * @return string
      */
     public function toString()
     {
         return $this->__toString();
     }
-    
+
     /**
      * Return string representation of the object
-     * 
+     *
      * @return string
      */
     public function __toString()
@@ -993,4 +1113,3 @@ class PhingFile {
         return $this->getPath();
     }
 }
-
